# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/audio/audio.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensory_cloud.generated.validate import validate_pb2 as validate_dot_validate__pb2
from sensory_cloud.generated.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='v1/audio/audio.proto',
  package='sensory.api.v1.audio',
  syntax='proto3',
  serialized_options=b'\n\034ai.sensorycloud.api.v1.audioB\026SensoryApiV1AudioProtoP\001Z:gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/audio',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14v1/audio/audio.proto\x12\x14sensory.api.v1.audio\x1a\x17validate/validate.proto\x1a\x13\x63ommon/common.proto\"\x12\n\x10GetModelsRequest\"\xf2\x01\n\nAudioModel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cisEnrollable\x18\x02 \x01(\x08\x12\x30\n\tmodelType\x18\x03 \x01(\x0e\x32\x1d.sensory.api.common.ModelType\x12\x13\n\x0b\x66ixedPhrase\x18\x04 \x01(\t\x12\x12\n\nsampleRate\x18\x05 \x01(\x05\x12\x10\n\x08versions\x18\x06 \x03(\t\x12\x36\n\ntechnology\x18\x07 \x01(\x0e\x32\".sensory.api.common.TechnologyType\x12\x1b\n\x13isLivenessSupported\x18\x08 \x01(\x08\"\x7f\n AudioRequestPostProcessingAction\x12\x10\n\x08\x61\x63tionId\x18\x01 \x01(\t\x12I\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32/.sensory.api.v1.audio.AudioPostProcessingActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"\x80\x01\n!AudioResponsePostProcessingAction\x12\x10\n\x08\x61\x63tionId\x18\x01 \x01(\t\x12I\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32/.sensory.api.v1.audio.AudioPostProcessingActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"E\n\x11GetModelsResponse\x12\x30\n\x06models\x18\x01 \x03(\x0b\x32 .sensory.api.v1.audio.AudioModel\"\x8a\x01\n\x17\x43reateEnrollmentRequest\x12>\n\x06\x63onfig\x18\x01 \x01(\x0b\x32,.sensory.api.v1.audio.CreateEnrollmentConfigH\x00\x12\x16\n\x0c\x61udioContent\x18\x02 \x01(\x0cH\x00\x42\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"\x82\x01\n\x13\x41uthenticateRequest\x12:\n\x06\x63onfig\x18\x01 \x01(\x0b\x32(.sensory.api.v1.audio.AuthenticateConfigH\x00\x12\x16\n\x0c\x61udioContent\x18\x02 \x01(\x0cH\x00\x42\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"\xda\x01\n\x14ValidateEventRequest\x12;\n\x06\x63onfig\x18\x01 \x01(\x0b\x32).sensory.api.v1.audio.ValidateEventConfigH\x00\x12\x16\n\x0c\x61udioContent\x18\x02 \x01(\x0cH\x00\x12T\n\x14postProcessingAction\x18\n \x01(\x0b\x32\x36.sensory.api.v1.audio.AudioRequestPostProcessingActionB\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"\x92\x01\n\x1a\x43reateEnrolledEventRequest\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x31.sensory.api.v1.audio.CreateEnrollmentEventConfigH\x00\x12\x16\n\x0c\x61udioContent\x18\x02 \x01(\x0cH\x00\x42\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"\x94\x01\n\x1cValidateEnrolledEventRequest\x12\x43\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x31.sensory.api.v1.audio.ValidateEnrolledEventConfigH\x00\x12\x16\n\x0c\x61udioContent\x18\x02 \x01(\x0cH\x00\x42\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"\xd4\x01\n\x11TranscribeRequest\x12\x38\n\x06\x63onfig\x18\x01 \x01(\x0b\x32&.sensory.api.v1.audio.TranscribeConfigH\x00\x12\x16\n\x0c\x61udioContent\x18\x02 \x01(\x0cH\x00\x12T\n\x14postProcessingAction\x18\n \x01(\x0b\x32\x36.sensory.api.v1.audio.AudioRequestPostProcessingActionB\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"e\n\x17SynthesizeSpeechRequest\x12\x0e\n\x06phrase\x18\x01 \x01(\t\x12:\n\x06\x63onfig\x18\x02 \x01(\x0b\x32*.sensory.api.v1.audio.VoiceSynthesisConfig\"\xfa\x01\n\x18\x43reateEnrollmentResponse\x12\x17\n\x0fpercentComplete\x18\x01 \x01(\x03\x12\x13\n\x0b\x61udioEnergy\x18\x02 \x01(\x02\x12\x14\n\x0c\x65nrollmentId\x18\x03 \x01(\t\x12\x11\n\tmodelName\x18\x04 \x01(\t\x12\x14\n\x0cmodelVersion\x18\x05 \x01(\t\x12\x13\n\x0bmodelPrompt\x18\x06 \x01(\t\x12\x1e\n\x16percentSegmentComplete\x18\x07 \x01(\x03\x12<\n\x0f\x65nrollmentToken\x18\x08 \x01(\x0b\x32#.sensory.api.common.EnrollmentToken\"\xc9\x01\n\x14\x41uthenticateResponse\x12\x13\n\x0b\x61udioEnergy\x18\x01 \x01(\x02\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x30\n\x05token\x18\x03 \x01(\x0b\x32!.sensory.api.common.TokenResponse\x12\x0e\n\x06userId\x18\x04 \x01(\t\x12\x14\n\x0c\x65nrollmentId\x18\x05 \x01(\t\x12\x13\n\x0bmodelPrompt\x18\x06 \x01(\t\x12\x1e\n\x16percentSegmentComplete\x18\x07 \x01(\x03\"\xb5\x01\n\x15ValidateEventResponse\x12\x13\n\x0b\x61udioEnergy\x18\x01 \x01(\x02\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x10\n\x08resultId\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x02\x12U\n\x14postProcessingAction\x18\n \x01(\x0b\x32\x37.sensory.api.v1.audio.AudioResponsePostProcessingAction\"\x80\x01\n\x1dValidateEnrolledEventResponse\x12\x13\n\x0b\x61udioEnergy\x18\x01 \x01(\x02\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x14\n\x0c\x65nrollmentId\x18\x03 \x01(\t\x12\x0e\n\x06userId\x18\x04 \x01(\t\x12\x13\n\x0bmodelPrompt\x18\x05 \x01(\t\"\xa1\x01\n\x0eTranscribeWord\x12\x13\n\x0b\x62\x65gintimeMs\x18\x01 \x01(\x04\x12\x11\n\tendtimeMs\x18\x02 \x01(\x04\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\x32\n\twordState\x18\x04 \x01(\x0e\x32\x1f.sensory.api.v1.audio.WordState\x12\x11\n\twordIndex\x18\x05 \x01(\x04\x12\x0c\n\x04word\x18\x06 \x01(\t\"|\n\x16TranscribeWordResponse\x12\x33\n\x05words\x18\x01 \x03(\x0b\x32$.sensory.api.v1.audio.TranscribeWord\x12\x16\n\x0e\x66irstWordIndex\x18\x02 \x01(\x04\x12\x15\n\rlastWordIndex\x18\x03 \x01(\x04\"\xda\x01\n\x12TranscribeResponse\x12\x13\n\x0b\x61udioEnergy\x18\x01 \x01(\x02\x12>\n\x08wordList\x18\x04 \x01(\x0b\x32,.sensory.api.v1.audio.TranscribeWordResponse\x12\x18\n\x10hasVoiceActivity\x18\x05 \x01(\x08\x12U\n\x14postProcessingAction\x18\n \x01(\x0b\x32\x37.sensory.api.v1.audio.AudioResponsePostProcessingAction\"|\n\x18SynthesizeSpeechResponse\x12\x33\n\x06\x63onfig\x18\x01 \x01(\x0b\x32!.sensory.api.v1.audio.AudioConfigH\x00\x12\x16\n\x0c\x61udioContent\x18\x02 \x01(\x0cH\x00\x42\x13\n\x11streamingResponse\"\xa0\x03\n\x16\x43reateEnrollmentConfig\x12:\n\x05\x61udio\x18\x01 \x01(\x0b\x32!.sensory.api.v1.audio.AudioConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x06userId\x18\x02 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1b\n\x08\x64\x65viceId\x18\x03 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1d\n\tmodelName\x18\x04 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x1d\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x08\xfa\x42\x05r\x03\x18\xff\x07\x12\x19\n\x11isLivenessEnabled\x18\x06 \x01(\x08\x12,\n\x17\x65nrollmentNumUtterances\x18\x07 \x01(\rB\t\xfa\x42\x06*\x04\x18\n(\x00H\x00\x12-\n\x12\x65nrollmentDuration\x18\x08 \x01(\x02\x42\x0f\xfa\x42\x0c\n\n\x1d\x00\x00pA-\x00\x00\x00\x00H\x00\x12\x1c\n\x0breferenceId\x18\t \x01(\tB\x07\xfa\x42\x04r\x02\x18\x7f\x12.\n&disableServerEnrollmentTemplateStorage\x18\n \x01(\x08\x42\x0e\n\x0c\x65nrollLength\"\xb5\x03\n\x12\x41uthenticateConfig\x12:\n\x05\x61udio\x18\x01 \x01(\x0b\x32!.sensory.api.v1.audio.AudioConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12 \n\x0c\x65nrollmentId\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x12\x1b\n\x11\x65nrollmentGroupId\x18\x03 \x01(\tH\x00\x12\x16\n\x0e\x64oIncludeToken\x18\x04 \x01(\x08\x12I\n\x0bsensitivity\x18\x05 \x01(\x0e\x32*.sensory.api.v1.audio.ThresholdSensitivityB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12V\n\x08security\x18\x06 \x01(\x0e\x32:.sensory.api.v1.audio.AuthenticateConfig.ThresholdSecurityB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x19\n\x11isLivenessEnabled\x18\x07 \x01(\x08\x12\x17\n\x0f\x65nrollmentToken\x18\x08 \x01(\x0c\"&\n\x11ThresholdSecurity\x12\x08\n\x04HIGH\x10\x00\x12\x07\n\x03LOW\x10\x01\x42\r\n\x06\x61uthId\x12\x03\xf8\x42\x01\"\xd6\x01\n\x13ValidateEventConfig\x12:\n\x05\x61udio\x18\x01 \x01(\x0b\x32!.sensory.api.v1.audio.AudioConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1d\n\tmodelName\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x19\n\x06userId\x18\x03 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12I\n\x0bsensitivity\x18\x04 \x01(\x0e\x32*.sensory.api.v1.audio.ThresholdSensitivityB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"\xbd\x02\n\x1b\x43reateEnrollmentEventConfig\x12:\n\x05\x61udio\x18\x01 \x01(\x0b\x32!.sensory.api.v1.audio.AudioConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x06userId\x18\x02 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1d\n\tmodelName\x18\x03 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x1d\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x18\xff\x07\x12,\n\x17\x65nrollmentNumUtterances\x18\x05 \x01(\rB\t\xfa\x42\x06*\x04\x18\n(\x00H\x00\x12-\n\x12\x65nrollmentDuration\x18\x06 \x01(\x02\x42\x0f\xfa\x42\x0c\n\n\x1d\x00\x00pA-\x00\x00\x00\x00H\x00\x12\x1c\n\x0breferenceId\x18\x07 \x01(\tB\x07\xfa\x42\x04r\x02\x18\x7f\x42\x0e\n\x0c\x65nrollLength\"\x8b\x02\n\x1bValidateEnrolledEventConfig\x12:\n\x05\x61udio\x18\x01 \x01(\x0b\x32!.sensory.api.v1.audio.AudioConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12 \n\x0c\x65nrollmentId\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x12\x1b\n\x11\x65nrollmentGroupId\x18\x03 \x01(\tH\x00\x12I\n\x0bsensitivity\x18\x04 \x01(\x0e\x32*.sensory.api.v1.audio.ThresholdSensitivityB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x17\n\x0f\x65nrollmentToken\x18\x05 \x01(\x0c\x42\r\n\x06\x61uthId\x12\x03\xf8\x42\x01\"2\n\x15\x43ustomVocabularyWords\x12\x19\n\x05words\x18\x01 \x03(\tB\n\xfa\x42\x07\x92\x01\x04\x08\x01\x10\x64\"\xd6\x03\n\x10TranscribeConfig\x12:\n\x05\x61udio\x18\x01 \x01(\x0b\x32!.sensory.api.v1.audio.AudioConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1d\n\tmodelName\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x19\n\x06userId\x18\x03 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\'\n\x1f\x65nablePunctuationCapitalization\x18\x04 \x01(\x08\x12\x19\n\x11\x64oSingleUtterance\x18\x05 \x01(\x08\x12\x42\n\x0evadSensitivity\x18\x06 \x01(\x0e\x32*.sensory.api.v1.audio.ThresholdSensitivity\x12\x13\n\x0bvadDuration\x18\x07 \x01(\x02\x12N\n\x1a\x63ustomVocabRewardThreshold\x18\x08 \x01(\x0e\x32*.sensory.api.v1.audio.ThresholdSensitivity\x12\x1a\n\x12\x63ustomVocabularyId\x18\t \x01(\t\x12\x43\n\x0e\x63ustomWordList\x18\n \x01(\x0b\x32+.sensory.api.v1.audio.CustomVocabularyWords\"\xeb\x01\n\x0b\x41udioConfig\x12K\n\x08\x65ncoding\x18\x01 \x01(\x0e\x32/.sensory.api.v1.audio.AudioConfig.AudioEncodingB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12!\n\x0fsampleRateHertz\x18\x02 \x01(\x05\x42\x08\xfa\x42\x05\x1a\x03(\xc0>\x12\"\n\x11\x61udioChannelCount\x18\x03 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02 \x00\x12\x14\n\x0clanguageCode\x18\x04 \x01(\t\"2\n\rAudioEncoding\x12\x0c\n\x08LINEAR16\x10\x00\x12\x08\n\x04\x46LAC\x10\x01\x12\t\n\x05MULAW\x10\x02\"b\n\x14VoiceSynthesisConfig\x12\x1d\n\tmodelName\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12%\n\x0fsampleRateHertz\x18\x03 \x01(\x05\x42\x0c\xfa\x42\t\x1a\x07\x18\x80\xee\x05(\xc0>J\x04\x08\x01\x10\x02*I\n\x19\x41udioPostProcessingAction\x12\x0b\n\x07NOT_SET\x10\x00\x12\t\n\x05\x46LUSH\x10\x01\x12\t\n\x05RESET\x10\x02\x12\t\n\x05\x46INAL\x10\x03*7\n\tWordState\x12\x15\n\x11WORDSTATE_PENDING\x10\x00\x12\x13\n\x0fWORDSTATE_FINAL\x10\x01*N\n\x14ThresholdSensitivity\x12\n\n\x06LOWEST\x10\x00\x12\x07\n\x03LOW\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\x08\n\x04HIGH\x10\x03\x12\x0b\n\x07HIGHEST\x10\x04\x32m\n\x0b\x41udioModels\x12^\n\tGetModels\x12&.sensory.api.v1.audio.GetModelsRequest\x1a\'.sensory.api.v1.audio.GetModelsResponse\"\x00\x32\xf7\x01\n\x0f\x41udioBiometrics\x12w\n\x10\x43reateEnrollment\x12-.sensory.api.v1.audio.CreateEnrollmentRequest\x1a..sensory.api.v1.audio.CreateEnrollmentResponse\"\x00(\x01\x30\x01\x12k\n\x0c\x41uthenticate\x12).sensory.api.v1.audio.AuthenticateRequest\x1a*.sensory.api.v1.audio.AuthenticateResponse\"\x00(\x01\x30\x01\x32\x85\x03\n\x0b\x41udioEvents\x12n\n\rValidateEvent\x12*.sensory.api.v1.audio.ValidateEventRequest\x1a+.sensory.api.v1.audio.ValidateEventResponse\"\x00(\x01\x30\x01\x12}\n\x13\x43reateEnrolledEvent\x12\x30.sensory.api.v1.audio.CreateEnrolledEventRequest\x1a..sensory.api.v1.audio.CreateEnrollmentResponse\"\x00(\x01\x30\x01\x12\x86\x01\n\x15ValidateEnrolledEvent\x12\x32.sensory.api.v1.audio.ValidateEnrolledEventRequest\x1a\x33.sensory.api.v1.audio.ValidateEnrolledEventResponse\"\x00(\x01\x30\x01\x32|\n\x13\x41udioTranscriptions\x12\x65\n\nTranscribe\x12\'.sensory.api.v1.audio.TranscribeRequest\x1a(.sensory.api.v1.audio.TranscribeResponse\"\x00(\x01\x30\x01\x32\x87\x01\n\x0e\x41udioSynthesis\x12u\n\x10SynthesizeSpeech\x12-.sensory.api.v1.audio.SynthesizeSpeechRequest\x1a..sensory.api.v1.audio.SynthesizeSpeechResponse\"\x00\x30\x01\x42t\n\x1c\x61i.sensorycloud.api.v1.audioB\x16SensoryApiV1AudioProtoP\x01Z:gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/audiob\x06proto3'
  ,
  dependencies=[validate_dot_validate__pb2.DESCRIPTOR,common_dot_common__pb2.DESCRIPTOR,])

_AUDIOPOSTPROCESSINGACTION = _descriptor.EnumDescriptor(
  name='AudioPostProcessingAction',
  full_name='sensory.api.v1.audio.AudioPostProcessingAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLUSH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESET', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5739,
  serialized_end=5812,
)
_sym_db.RegisterEnumDescriptor(_AUDIOPOSTPROCESSINGACTION)

AudioPostProcessingAction = enum_type_wrapper.EnumTypeWrapper(_AUDIOPOSTPROCESSINGACTION)
_WORDSTATE = _descriptor.EnumDescriptor(
  name='WordState',
  full_name='sensory.api.v1.audio.WordState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WORDSTATE_PENDING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WORDSTATE_FINAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5814,
  serialized_end=5869,
)
_sym_db.RegisterEnumDescriptor(_WORDSTATE)

WordState = enum_type_wrapper.EnumTypeWrapper(_WORDSTATE)
_THRESHOLDSENSITIVITY = _descriptor.EnumDescriptor(
  name='ThresholdSensitivity',
  full_name='sensory.api.v1.audio.ThresholdSensitivity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOWEST', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIUM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHEST', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5871,
  serialized_end=5949,
)
_sym_db.RegisterEnumDescriptor(_THRESHOLDSENSITIVITY)

ThresholdSensitivity = enum_type_wrapper.EnumTypeWrapper(_THRESHOLDSENSITIVITY)
NOT_SET = 0
FLUSH = 1
RESET = 2
FINAL = 3
WORDSTATE_PENDING = 0
WORDSTATE_FINAL = 1
LOWEST = 0
LOW = 1
MEDIUM = 2
HIGH = 3
HIGHEST = 4


_AUTHENTICATECONFIG_THRESHOLDSECURITY = _descriptor.EnumDescriptor(
  name='ThresholdSecurity',
  full_name='sensory.api.v1.audio.AuthenticateConfig.ThresholdSecurity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4014,
  serialized_end=4052,
)
_sym_db.RegisterEnumDescriptor(_AUTHENTICATECONFIG_THRESHOLDSECURITY)

_AUDIOCONFIG_AUDIOENCODING = _descriptor.EnumDescriptor(
  name='AudioEncoding',
  full_name='sensory.api.v1.audio.AudioConfig.AudioEncoding',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LINEAR16', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLAC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULAW', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5587,
  serialized_end=5637,
)
_sym_db.RegisterEnumDescriptor(_AUDIOCONFIG_AUDIOENCODING)


_GETMODELSREQUEST = _descriptor.Descriptor(
  name='GetModelsRequest',
  full_name='sensory.api.v1.audio.GetModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=110,
)


_AUDIOMODEL = _descriptor.Descriptor(
  name='AudioModel',
  full_name='sensory.api.v1.audio.AudioModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.v1.audio.AudioModel.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isEnrollable', full_name='sensory.api.v1.audio.AudioModel.isEnrollable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelType', full_name='sensory.api.v1.audio.AudioModel.modelType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixedPhrase', full_name='sensory.api.v1.audio.AudioModel.fixedPhrase', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampleRate', full_name='sensory.api.v1.audio.AudioModel.sampleRate', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='versions', full_name='sensory.api.v1.audio.AudioModel.versions', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='technology', full_name='sensory.api.v1.audio.AudioModel.technology', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLivenessSupported', full_name='sensory.api.v1.audio.AudioModel.isLivenessSupported', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=355,
)


_AUDIOREQUESTPOSTPROCESSINGACTION = _descriptor.Descriptor(
  name='AudioRequestPostProcessingAction',
  full_name='sensory.api.v1.audio.AudioRequestPostProcessingAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionId', full_name='sensory.api.v1.audio.AudioRequestPostProcessingAction.actionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='sensory.api.v1.audio.AudioRequestPostProcessingAction.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=484,
)


_AUDIORESPONSEPOSTPROCESSINGACTION = _descriptor.Descriptor(
  name='AudioResponsePostProcessingAction',
  full_name='sensory.api.v1.audio.AudioResponsePostProcessingAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionId', full_name='sensory.api.v1.audio.AudioResponsePostProcessingAction.actionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='sensory.api.v1.audio.AudioResponsePostProcessingAction.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=487,
  serialized_end=615,
)


_GETMODELSRESPONSE = _descriptor.Descriptor(
  name='GetModelsResponse',
  full_name='sensory.api.v1.audio.GetModelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='models', full_name='sensory.api.v1.audio.GetModelsResponse.models', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=686,
)


_CREATEENROLLMENTREQUEST = _descriptor.Descriptor(
  name='CreateEnrollmentRequest',
  full_name='sensory.api.v1.audio.CreateEnrollmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.audio.CreateEnrollmentRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioContent', full_name='sensory.api.v1.audio.CreateEnrollmentRequest.audioContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.audio.CreateEnrollmentRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=689,
  serialized_end=827,
)


_AUTHENTICATEREQUEST = _descriptor.Descriptor(
  name='AuthenticateRequest',
  full_name='sensory.api.v1.audio.AuthenticateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.audio.AuthenticateRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioContent', full_name='sensory.api.v1.audio.AuthenticateRequest.audioContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.audio.AuthenticateRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=830,
  serialized_end=960,
)


_VALIDATEEVENTREQUEST = _descriptor.Descriptor(
  name='ValidateEventRequest',
  full_name='sensory.api.v1.audio.ValidateEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.audio.ValidateEventRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioContent', full_name='sensory.api.v1.audio.ValidateEventRequest.audioContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postProcessingAction', full_name='sensory.api.v1.audio.ValidateEventRequest.postProcessingAction', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.audio.ValidateEventRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=963,
  serialized_end=1181,
)


_CREATEENROLLEDEVENTREQUEST = _descriptor.Descriptor(
  name='CreateEnrolledEventRequest',
  full_name='sensory.api.v1.audio.CreateEnrolledEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.audio.CreateEnrolledEventRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioContent', full_name='sensory.api.v1.audio.CreateEnrolledEventRequest.audioContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.audio.CreateEnrolledEventRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1184,
  serialized_end=1330,
)


_VALIDATEENROLLEDEVENTREQUEST = _descriptor.Descriptor(
  name='ValidateEnrolledEventRequest',
  full_name='sensory.api.v1.audio.ValidateEnrolledEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.audio.ValidateEnrolledEventRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioContent', full_name='sensory.api.v1.audio.ValidateEnrolledEventRequest.audioContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.audio.ValidateEnrolledEventRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1333,
  serialized_end=1481,
)


_TRANSCRIBEREQUEST = _descriptor.Descriptor(
  name='TranscribeRequest',
  full_name='sensory.api.v1.audio.TranscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.audio.TranscribeRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioContent', full_name='sensory.api.v1.audio.TranscribeRequest.audioContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postProcessingAction', full_name='sensory.api.v1.audio.TranscribeRequest.postProcessingAction', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.audio.TranscribeRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1484,
  serialized_end=1696,
)


_SYNTHESIZESPEECHREQUEST = _descriptor.Descriptor(
  name='SynthesizeSpeechRequest',
  full_name='sensory.api.v1.audio.SynthesizeSpeechRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phrase', full_name='sensory.api.v1.audio.SynthesizeSpeechRequest.phrase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.audio.SynthesizeSpeechRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1698,
  serialized_end=1799,
)


_CREATEENROLLMENTRESPONSE = _descriptor.Descriptor(
  name='CreateEnrollmentResponse',
  full_name='sensory.api.v1.audio.CreateEnrollmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentComplete', full_name='sensory.api.v1.audio.CreateEnrollmentResponse.percentComplete', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioEnergy', full_name='sensory.api.v1.audio.CreateEnrollmentResponse.audioEnergy', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentId', full_name='sensory.api.v1.audio.CreateEnrollmentResponse.enrollmentId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.audio.CreateEnrollmentResponse.modelName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelVersion', full_name='sensory.api.v1.audio.CreateEnrollmentResponse.modelVersion', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelPrompt', full_name='sensory.api.v1.audio.CreateEnrollmentResponse.modelPrompt', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentSegmentComplete', full_name='sensory.api.v1.audio.CreateEnrollmentResponse.percentSegmentComplete', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentToken', full_name='sensory.api.v1.audio.CreateEnrollmentResponse.enrollmentToken', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1802,
  serialized_end=2052,
)


_AUTHENTICATERESPONSE = _descriptor.Descriptor(
  name='AuthenticateResponse',
  full_name='sensory.api.v1.audio.AuthenticateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audioEnergy', full_name='sensory.api.v1.audio.AuthenticateResponse.audioEnergy', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='sensory.api.v1.audio.AuthenticateResponse.success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='sensory.api.v1.audio.AuthenticateResponse.token', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.audio.AuthenticateResponse.userId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentId', full_name='sensory.api.v1.audio.AuthenticateResponse.enrollmentId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelPrompt', full_name='sensory.api.v1.audio.AuthenticateResponse.modelPrompt', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentSegmentComplete', full_name='sensory.api.v1.audio.AuthenticateResponse.percentSegmentComplete', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2055,
  serialized_end=2256,
)


_VALIDATEEVENTRESPONSE = _descriptor.Descriptor(
  name='ValidateEventResponse',
  full_name='sensory.api.v1.audio.ValidateEventResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audioEnergy', full_name='sensory.api.v1.audio.ValidateEventResponse.audioEnergy', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='sensory.api.v1.audio.ValidateEventResponse.success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resultId', full_name='sensory.api.v1.audio.ValidateEventResponse.resultId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='sensory.api.v1.audio.ValidateEventResponse.score', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postProcessingAction', full_name='sensory.api.v1.audio.ValidateEventResponse.postProcessingAction', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2259,
  serialized_end=2440,
)


_VALIDATEENROLLEDEVENTRESPONSE = _descriptor.Descriptor(
  name='ValidateEnrolledEventResponse',
  full_name='sensory.api.v1.audio.ValidateEnrolledEventResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audioEnergy', full_name='sensory.api.v1.audio.ValidateEnrolledEventResponse.audioEnergy', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='sensory.api.v1.audio.ValidateEnrolledEventResponse.success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentId', full_name='sensory.api.v1.audio.ValidateEnrolledEventResponse.enrollmentId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.audio.ValidateEnrolledEventResponse.userId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelPrompt', full_name='sensory.api.v1.audio.ValidateEnrolledEventResponse.modelPrompt', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2443,
  serialized_end=2571,
)


_TRANSCRIBEWORD = _descriptor.Descriptor(
  name='TranscribeWord',
  full_name='sensory.api.v1.audio.TranscribeWord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='begintimeMs', full_name='sensory.api.v1.audio.TranscribeWord.begintimeMs', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endtimeMs', full_name='sensory.api.v1.audio.TranscribeWord.endtimeMs', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='sensory.api.v1.audio.TranscribeWord.confidence', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wordState', full_name='sensory.api.v1.audio.TranscribeWord.wordState', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wordIndex', full_name='sensory.api.v1.audio.TranscribeWord.wordIndex', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='word', full_name='sensory.api.v1.audio.TranscribeWord.word', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2574,
  serialized_end=2735,
)


_TRANSCRIBEWORDRESPONSE = _descriptor.Descriptor(
  name='TranscribeWordResponse',
  full_name='sensory.api.v1.audio.TranscribeWordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='words', full_name='sensory.api.v1.audio.TranscribeWordResponse.words', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firstWordIndex', full_name='sensory.api.v1.audio.TranscribeWordResponse.firstWordIndex', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastWordIndex', full_name='sensory.api.v1.audio.TranscribeWordResponse.lastWordIndex', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2737,
  serialized_end=2861,
)


_TRANSCRIBERESPONSE = _descriptor.Descriptor(
  name='TranscribeResponse',
  full_name='sensory.api.v1.audio.TranscribeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audioEnergy', full_name='sensory.api.v1.audio.TranscribeResponse.audioEnergy', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wordList', full_name='sensory.api.v1.audio.TranscribeResponse.wordList', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hasVoiceActivity', full_name='sensory.api.v1.audio.TranscribeResponse.hasVoiceActivity', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postProcessingAction', full_name='sensory.api.v1.audio.TranscribeResponse.postProcessingAction', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2864,
  serialized_end=3082,
)


_SYNTHESIZESPEECHRESPONSE = _descriptor.Descriptor(
  name='SynthesizeSpeechResponse',
  full_name='sensory.api.v1.audio.SynthesizeSpeechResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.audio.SynthesizeSpeechResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioContent', full_name='sensory.api.v1.audio.SynthesizeSpeechResponse.audioContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingResponse', full_name='sensory.api.v1.audio.SynthesizeSpeechResponse.streamingResponse',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3084,
  serialized_end=3208,
)


_CREATEENROLLMENTCONFIG = _descriptor.Descriptor(
  name='CreateEnrollmentConfig',
  full_name='sensory.api.v1.audio.CreateEnrollmentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio', full_name='sensory.api.v1.audio.CreateEnrollmentConfig.audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.audio.CreateEnrollmentConfig.userId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceId', full_name='sensory.api.v1.audio.CreateEnrollmentConfig.deviceId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.audio.CreateEnrollmentConfig.modelName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='sensory.api.v1.audio.CreateEnrollmentConfig.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\030\377\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLivenessEnabled', full_name='sensory.api.v1.audio.CreateEnrollmentConfig.isLivenessEnabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentNumUtterances', full_name='sensory.api.v1.audio.CreateEnrollmentConfig.enrollmentNumUtterances', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\n(\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentDuration', full_name='sensory.api.v1.audio.CreateEnrollmentConfig.enrollmentDuration', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\014\n\n\035\000\000pA-\000\000\000\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referenceId', full_name='sensory.api.v1.audio.CreateEnrollmentConfig.referenceId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disableServerEnrollmentTemplateStorage', full_name='sensory.api.v1.audio.CreateEnrollmentConfig.disableServerEnrollmentTemplateStorage', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='enrollLength', full_name='sensory.api.v1.audio.CreateEnrollmentConfig.enrollLength',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3211,
  serialized_end=3627,
)


_AUTHENTICATECONFIG = _descriptor.Descriptor(
  name='AuthenticateConfig',
  full_name='sensory.api.v1.audio.AuthenticateConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio', full_name='sensory.api.v1.audio.AuthenticateConfig.audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentId', full_name='sensory.api.v1.audio.AuthenticateConfig.enrollmentId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\260\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentGroupId', full_name='sensory.api.v1.audio.AuthenticateConfig.enrollmentGroupId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doIncludeToken', full_name='sensory.api.v1.audio.AuthenticateConfig.doIncludeToken', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensitivity', full_name='sensory.api.v1.audio.AuthenticateConfig.sensitivity', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security', full_name='sensory.api.v1.audio.AuthenticateConfig.security', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLivenessEnabled', full_name='sensory.api.v1.audio.AuthenticateConfig.isLivenessEnabled', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentToken', full_name='sensory.api.v1.audio.AuthenticateConfig.enrollmentToken', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AUTHENTICATECONFIG_THRESHOLDSECURITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='authId', full_name='sensory.api.v1.audio.AuthenticateConfig.authId',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=3630,
  serialized_end=4067,
)


_VALIDATEEVENTCONFIG = _descriptor.Descriptor(
  name='ValidateEventConfig',
  full_name='sensory.api.v1.audio.ValidateEventConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio', full_name='sensory.api.v1.audio.ValidateEventConfig.audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.audio.ValidateEventConfig.modelName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.audio.ValidateEventConfig.userId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensitivity', full_name='sensory.api.v1.audio.ValidateEventConfig.sensitivity', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4070,
  serialized_end=4284,
)


_CREATEENROLLMENTEVENTCONFIG = _descriptor.Descriptor(
  name='CreateEnrollmentEventConfig',
  full_name='sensory.api.v1.audio.CreateEnrollmentEventConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio', full_name='sensory.api.v1.audio.CreateEnrollmentEventConfig.audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.audio.CreateEnrollmentEventConfig.userId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.audio.CreateEnrollmentEventConfig.modelName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='sensory.api.v1.audio.CreateEnrollmentEventConfig.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\030\377\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentNumUtterances', full_name='sensory.api.v1.audio.CreateEnrollmentEventConfig.enrollmentNumUtterances', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\n(\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentDuration', full_name='sensory.api.v1.audio.CreateEnrollmentEventConfig.enrollmentDuration', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\014\n\n\035\000\000pA-\000\000\000\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referenceId', full_name='sensory.api.v1.audio.CreateEnrollmentEventConfig.referenceId', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='enrollLength', full_name='sensory.api.v1.audio.CreateEnrollmentEventConfig.enrollLength',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4287,
  serialized_end=4604,
)


_VALIDATEENROLLEDEVENTCONFIG = _descriptor.Descriptor(
  name='ValidateEnrolledEventConfig',
  full_name='sensory.api.v1.audio.ValidateEnrolledEventConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio', full_name='sensory.api.v1.audio.ValidateEnrolledEventConfig.audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentId', full_name='sensory.api.v1.audio.ValidateEnrolledEventConfig.enrollmentId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\260\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentGroupId', full_name='sensory.api.v1.audio.ValidateEnrolledEventConfig.enrollmentGroupId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensitivity', full_name='sensory.api.v1.audio.ValidateEnrolledEventConfig.sensitivity', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentToken', full_name='sensory.api.v1.audio.ValidateEnrolledEventConfig.enrollmentToken', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='authId', full_name='sensory.api.v1.audio.ValidateEnrolledEventConfig.authId',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=4607,
  serialized_end=4874,
)


_CUSTOMVOCABULARYWORDS = _descriptor.Descriptor(
  name='CustomVocabularyWords',
  full_name='sensory.api.v1.audio.CustomVocabularyWords',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='words', full_name='sensory.api.v1.audio.CustomVocabularyWords.words', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\222\001\004\010\001\020d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4876,
  serialized_end=4926,
)


_TRANSCRIBECONFIG = _descriptor.Descriptor(
  name='TranscribeConfig',
  full_name='sensory.api.v1.audio.TranscribeConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio', full_name='sensory.api.v1.audio.TranscribeConfig.audio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.audio.TranscribeConfig.modelName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.audio.TranscribeConfig.userId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enablePunctuationCapitalization', full_name='sensory.api.v1.audio.TranscribeConfig.enablePunctuationCapitalization', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doSingleUtterance', full_name='sensory.api.v1.audio.TranscribeConfig.doSingleUtterance', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vadSensitivity', full_name='sensory.api.v1.audio.TranscribeConfig.vadSensitivity', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vadDuration', full_name='sensory.api.v1.audio.TranscribeConfig.vadDuration', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customVocabRewardThreshold', full_name='sensory.api.v1.audio.TranscribeConfig.customVocabRewardThreshold', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customVocabularyId', full_name='sensory.api.v1.audio.TranscribeConfig.customVocabularyId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customWordList', full_name='sensory.api.v1.audio.TranscribeConfig.customWordList', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4929,
  serialized_end=5399,
)


_AUDIOCONFIG = _descriptor.Descriptor(
  name='AudioConfig',
  full_name='sensory.api.v1.audio.AudioConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoding', full_name='sensory.api.v1.audio.AudioConfig.encoding', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampleRateHertz', full_name='sensory.api.v1.audio.AudioConfig.sampleRateHertz', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\032\003(\300>', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioChannelCount', full_name='sensory.api.v1.audio.AudioConfig.audioChannelCount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004\032\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='languageCode', full_name='sensory.api.v1.audio.AudioConfig.languageCode', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AUDIOCONFIG_AUDIOENCODING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5402,
  serialized_end=5637,
)


_VOICESYNTHESISCONFIG = _descriptor.Descriptor(
  name='VoiceSynthesisConfig',
  full_name='sensory.api.v1.audio.VoiceSynthesisConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.audio.VoiceSynthesisConfig.modelName', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampleRateHertz', full_name='sensory.api.v1.audio.VoiceSynthesisConfig.sampleRateHertz', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t\032\007\030\200\356\005(\300>', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5639,
  serialized_end=5737,
)

_AUDIOMODEL.fields_by_name['modelType'].enum_type = common_dot_common__pb2._MODELTYPE
_AUDIOMODEL.fields_by_name['technology'].enum_type = common_dot_common__pb2._TECHNOLOGYTYPE
_AUDIOREQUESTPOSTPROCESSINGACTION.fields_by_name['action'].enum_type = _AUDIOPOSTPROCESSINGACTION
_AUDIORESPONSEPOSTPROCESSINGACTION.fields_by_name['action'].enum_type = _AUDIOPOSTPROCESSINGACTION
_GETMODELSRESPONSE.fields_by_name['models'].message_type = _AUDIOMODEL
_CREATEENROLLMENTREQUEST.fields_by_name['config'].message_type = _CREATEENROLLMENTCONFIG
_CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _CREATEENROLLMENTREQUEST.fields_by_name['config'])
_CREATEENROLLMENTREQUEST.fields_by_name['config'].containing_oneof = _CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest']
_CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _CREATEENROLLMENTREQUEST.fields_by_name['audioContent'])
_CREATEENROLLMENTREQUEST.fields_by_name['audioContent'].containing_oneof = _CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest']
_AUTHENTICATEREQUEST.fields_by_name['config'].message_type = _AUTHENTICATECONFIG
_AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _AUTHENTICATEREQUEST.fields_by_name['config'])
_AUTHENTICATEREQUEST.fields_by_name['config'].containing_oneof = _AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest']
_AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _AUTHENTICATEREQUEST.fields_by_name['audioContent'])
_AUTHENTICATEREQUEST.fields_by_name['audioContent'].containing_oneof = _AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest']
_VALIDATEEVENTREQUEST.fields_by_name['config'].message_type = _VALIDATEEVENTCONFIG
_VALIDATEEVENTREQUEST.fields_by_name['postProcessingAction'].message_type = _AUDIOREQUESTPOSTPROCESSINGACTION
_VALIDATEEVENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _VALIDATEEVENTREQUEST.fields_by_name['config'])
_VALIDATEEVENTREQUEST.fields_by_name['config'].containing_oneof = _VALIDATEEVENTREQUEST.oneofs_by_name['streamingRequest']
_VALIDATEEVENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _VALIDATEEVENTREQUEST.fields_by_name['audioContent'])
_VALIDATEEVENTREQUEST.fields_by_name['audioContent'].containing_oneof = _VALIDATEEVENTREQUEST.oneofs_by_name['streamingRequest']
_CREATEENROLLEDEVENTREQUEST.fields_by_name['config'].message_type = _CREATEENROLLMENTEVENTCONFIG
_CREATEENROLLEDEVENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _CREATEENROLLEDEVENTREQUEST.fields_by_name['config'])
_CREATEENROLLEDEVENTREQUEST.fields_by_name['config'].containing_oneof = _CREATEENROLLEDEVENTREQUEST.oneofs_by_name['streamingRequest']
_CREATEENROLLEDEVENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _CREATEENROLLEDEVENTREQUEST.fields_by_name['audioContent'])
_CREATEENROLLEDEVENTREQUEST.fields_by_name['audioContent'].containing_oneof = _CREATEENROLLEDEVENTREQUEST.oneofs_by_name['streamingRequest']
_VALIDATEENROLLEDEVENTREQUEST.fields_by_name['config'].message_type = _VALIDATEENROLLEDEVENTCONFIG
_VALIDATEENROLLEDEVENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _VALIDATEENROLLEDEVENTREQUEST.fields_by_name['config'])
_VALIDATEENROLLEDEVENTREQUEST.fields_by_name['config'].containing_oneof = _VALIDATEENROLLEDEVENTREQUEST.oneofs_by_name['streamingRequest']
_VALIDATEENROLLEDEVENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _VALIDATEENROLLEDEVENTREQUEST.fields_by_name['audioContent'])
_VALIDATEENROLLEDEVENTREQUEST.fields_by_name['audioContent'].containing_oneof = _VALIDATEENROLLEDEVENTREQUEST.oneofs_by_name['streamingRequest']
_TRANSCRIBEREQUEST.fields_by_name['config'].message_type = _TRANSCRIBECONFIG
_TRANSCRIBEREQUEST.fields_by_name['postProcessingAction'].message_type = _AUDIOREQUESTPOSTPROCESSINGACTION
_TRANSCRIBEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _TRANSCRIBEREQUEST.fields_by_name['config'])
_TRANSCRIBEREQUEST.fields_by_name['config'].containing_oneof = _TRANSCRIBEREQUEST.oneofs_by_name['streamingRequest']
_TRANSCRIBEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _TRANSCRIBEREQUEST.fields_by_name['audioContent'])
_TRANSCRIBEREQUEST.fields_by_name['audioContent'].containing_oneof = _TRANSCRIBEREQUEST.oneofs_by_name['streamingRequest']
_SYNTHESIZESPEECHREQUEST.fields_by_name['config'].message_type = _VOICESYNTHESISCONFIG
_CREATEENROLLMENTRESPONSE.fields_by_name['enrollmentToken'].message_type = common_dot_common__pb2._ENROLLMENTTOKEN
_AUTHENTICATERESPONSE.fields_by_name['token'].message_type = common_dot_common__pb2._TOKENRESPONSE
_VALIDATEEVENTRESPONSE.fields_by_name['postProcessingAction'].message_type = _AUDIORESPONSEPOSTPROCESSINGACTION
_TRANSCRIBEWORD.fields_by_name['wordState'].enum_type = _WORDSTATE
_TRANSCRIBEWORDRESPONSE.fields_by_name['words'].message_type = _TRANSCRIBEWORD
_TRANSCRIBERESPONSE.fields_by_name['wordList'].message_type = _TRANSCRIBEWORDRESPONSE
_TRANSCRIBERESPONSE.fields_by_name['postProcessingAction'].message_type = _AUDIORESPONSEPOSTPROCESSINGACTION
_SYNTHESIZESPEECHRESPONSE.fields_by_name['config'].message_type = _AUDIOCONFIG
_SYNTHESIZESPEECHRESPONSE.oneofs_by_name['streamingResponse'].fields.append(
  _SYNTHESIZESPEECHRESPONSE.fields_by_name['config'])
_SYNTHESIZESPEECHRESPONSE.fields_by_name['config'].containing_oneof = _SYNTHESIZESPEECHRESPONSE.oneofs_by_name['streamingResponse']
_SYNTHESIZESPEECHRESPONSE.oneofs_by_name['streamingResponse'].fields.append(
  _SYNTHESIZESPEECHRESPONSE.fields_by_name['audioContent'])
_SYNTHESIZESPEECHRESPONSE.fields_by_name['audioContent'].containing_oneof = _SYNTHESIZESPEECHRESPONSE.oneofs_by_name['streamingResponse']
_CREATEENROLLMENTCONFIG.fields_by_name['audio'].message_type = _AUDIOCONFIG
_CREATEENROLLMENTCONFIG.oneofs_by_name['enrollLength'].fields.append(
  _CREATEENROLLMENTCONFIG.fields_by_name['enrollmentNumUtterances'])
_CREATEENROLLMENTCONFIG.fields_by_name['enrollmentNumUtterances'].containing_oneof = _CREATEENROLLMENTCONFIG.oneofs_by_name['enrollLength']
_CREATEENROLLMENTCONFIG.oneofs_by_name['enrollLength'].fields.append(
  _CREATEENROLLMENTCONFIG.fields_by_name['enrollmentDuration'])
_CREATEENROLLMENTCONFIG.fields_by_name['enrollmentDuration'].containing_oneof = _CREATEENROLLMENTCONFIG.oneofs_by_name['enrollLength']
_AUTHENTICATECONFIG.fields_by_name['audio'].message_type = _AUDIOCONFIG
_AUTHENTICATECONFIG.fields_by_name['sensitivity'].enum_type = _THRESHOLDSENSITIVITY
_AUTHENTICATECONFIG.fields_by_name['security'].enum_type = _AUTHENTICATECONFIG_THRESHOLDSECURITY
_AUTHENTICATECONFIG_THRESHOLDSECURITY.containing_type = _AUTHENTICATECONFIG
_AUTHENTICATECONFIG.oneofs_by_name['authId'].fields.append(
  _AUTHENTICATECONFIG.fields_by_name['enrollmentId'])
_AUTHENTICATECONFIG.fields_by_name['enrollmentId'].containing_oneof = _AUTHENTICATECONFIG.oneofs_by_name['authId']
_AUTHENTICATECONFIG.oneofs_by_name['authId'].fields.append(
  _AUTHENTICATECONFIG.fields_by_name['enrollmentGroupId'])
_AUTHENTICATECONFIG.fields_by_name['enrollmentGroupId'].containing_oneof = _AUTHENTICATECONFIG.oneofs_by_name['authId']
_VALIDATEEVENTCONFIG.fields_by_name['audio'].message_type = _AUDIOCONFIG
_VALIDATEEVENTCONFIG.fields_by_name['sensitivity'].enum_type = _THRESHOLDSENSITIVITY
_CREATEENROLLMENTEVENTCONFIG.fields_by_name['audio'].message_type = _AUDIOCONFIG
_CREATEENROLLMENTEVENTCONFIG.oneofs_by_name['enrollLength'].fields.append(
  _CREATEENROLLMENTEVENTCONFIG.fields_by_name['enrollmentNumUtterances'])
_CREATEENROLLMENTEVENTCONFIG.fields_by_name['enrollmentNumUtterances'].containing_oneof = _CREATEENROLLMENTEVENTCONFIG.oneofs_by_name['enrollLength']
_CREATEENROLLMENTEVENTCONFIG.oneofs_by_name['enrollLength'].fields.append(
  _CREATEENROLLMENTEVENTCONFIG.fields_by_name['enrollmentDuration'])
_CREATEENROLLMENTEVENTCONFIG.fields_by_name['enrollmentDuration'].containing_oneof = _CREATEENROLLMENTEVENTCONFIG.oneofs_by_name['enrollLength']
_VALIDATEENROLLEDEVENTCONFIG.fields_by_name['audio'].message_type = _AUDIOCONFIG
_VALIDATEENROLLEDEVENTCONFIG.fields_by_name['sensitivity'].enum_type = _THRESHOLDSENSITIVITY
_VALIDATEENROLLEDEVENTCONFIG.oneofs_by_name['authId'].fields.append(
  _VALIDATEENROLLEDEVENTCONFIG.fields_by_name['enrollmentId'])
_VALIDATEENROLLEDEVENTCONFIG.fields_by_name['enrollmentId'].containing_oneof = _VALIDATEENROLLEDEVENTCONFIG.oneofs_by_name['authId']
_VALIDATEENROLLEDEVENTCONFIG.oneofs_by_name['authId'].fields.append(
  _VALIDATEENROLLEDEVENTCONFIG.fields_by_name['enrollmentGroupId'])
_VALIDATEENROLLEDEVENTCONFIG.fields_by_name['enrollmentGroupId'].containing_oneof = _VALIDATEENROLLEDEVENTCONFIG.oneofs_by_name['authId']
_TRANSCRIBECONFIG.fields_by_name['audio'].message_type = _AUDIOCONFIG
_TRANSCRIBECONFIG.fields_by_name['vadSensitivity'].enum_type = _THRESHOLDSENSITIVITY
_TRANSCRIBECONFIG.fields_by_name['customVocabRewardThreshold'].enum_type = _THRESHOLDSENSITIVITY
_TRANSCRIBECONFIG.fields_by_name['customWordList'].message_type = _CUSTOMVOCABULARYWORDS
_AUDIOCONFIG.fields_by_name['encoding'].enum_type = _AUDIOCONFIG_AUDIOENCODING
_AUDIOCONFIG_AUDIOENCODING.containing_type = _AUDIOCONFIG
DESCRIPTOR.message_types_by_name['GetModelsRequest'] = _GETMODELSREQUEST
DESCRIPTOR.message_types_by_name['AudioModel'] = _AUDIOMODEL
DESCRIPTOR.message_types_by_name['AudioRequestPostProcessingAction'] = _AUDIOREQUESTPOSTPROCESSINGACTION
DESCRIPTOR.message_types_by_name['AudioResponsePostProcessingAction'] = _AUDIORESPONSEPOSTPROCESSINGACTION
DESCRIPTOR.message_types_by_name['GetModelsResponse'] = _GETMODELSRESPONSE
DESCRIPTOR.message_types_by_name['CreateEnrollmentRequest'] = _CREATEENROLLMENTREQUEST
DESCRIPTOR.message_types_by_name['AuthenticateRequest'] = _AUTHENTICATEREQUEST
DESCRIPTOR.message_types_by_name['ValidateEventRequest'] = _VALIDATEEVENTREQUEST
DESCRIPTOR.message_types_by_name['CreateEnrolledEventRequest'] = _CREATEENROLLEDEVENTREQUEST
DESCRIPTOR.message_types_by_name['ValidateEnrolledEventRequest'] = _VALIDATEENROLLEDEVENTREQUEST
DESCRIPTOR.message_types_by_name['TranscribeRequest'] = _TRANSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['SynthesizeSpeechRequest'] = _SYNTHESIZESPEECHREQUEST
DESCRIPTOR.message_types_by_name['CreateEnrollmentResponse'] = _CREATEENROLLMENTRESPONSE
DESCRIPTOR.message_types_by_name['AuthenticateResponse'] = _AUTHENTICATERESPONSE
DESCRIPTOR.message_types_by_name['ValidateEventResponse'] = _VALIDATEEVENTRESPONSE
DESCRIPTOR.message_types_by_name['ValidateEnrolledEventResponse'] = _VALIDATEENROLLEDEVENTRESPONSE
DESCRIPTOR.message_types_by_name['TranscribeWord'] = _TRANSCRIBEWORD
DESCRIPTOR.message_types_by_name['TranscribeWordResponse'] = _TRANSCRIBEWORDRESPONSE
DESCRIPTOR.message_types_by_name['TranscribeResponse'] = _TRANSCRIBERESPONSE
DESCRIPTOR.message_types_by_name['SynthesizeSpeechResponse'] = _SYNTHESIZESPEECHRESPONSE
DESCRIPTOR.message_types_by_name['CreateEnrollmentConfig'] = _CREATEENROLLMENTCONFIG
DESCRIPTOR.message_types_by_name['AuthenticateConfig'] = _AUTHENTICATECONFIG
DESCRIPTOR.message_types_by_name['ValidateEventConfig'] = _VALIDATEEVENTCONFIG
DESCRIPTOR.message_types_by_name['CreateEnrollmentEventConfig'] = _CREATEENROLLMENTEVENTCONFIG
DESCRIPTOR.message_types_by_name['ValidateEnrolledEventConfig'] = _VALIDATEENROLLEDEVENTCONFIG
DESCRIPTOR.message_types_by_name['CustomVocabularyWords'] = _CUSTOMVOCABULARYWORDS
DESCRIPTOR.message_types_by_name['TranscribeConfig'] = _TRANSCRIBECONFIG
DESCRIPTOR.message_types_by_name['AudioConfig'] = _AUDIOCONFIG
DESCRIPTOR.message_types_by_name['VoiceSynthesisConfig'] = _VOICESYNTHESISCONFIG
DESCRIPTOR.enum_types_by_name['AudioPostProcessingAction'] = _AUDIOPOSTPROCESSINGACTION
DESCRIPTOR.enum_types_by_name['WordState'] = _WORDSTATE
DESCRIPTOR.enum_types_by_name['ThresholdSensitivity'] = _THRESHOLDSENSITIVITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetModelsRequest = _reflection.GeneratedProtocolMessageType('GetModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELSREQUEST,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.GetModelsRequest)
  })
_sym_db.RegisterMessage(GetModelsRequest)

AudioModel = _reflection.GeneratedProtocolMessageType('AudioModel', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOMODEL,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.AudioModel)
  })
_sym_db.RegisterMessage(AudioModel)

AudioRequestPostProcessingAction = _reflection.GeneratedProtocolMessageType('AudioRequestPostProcessingAction', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOREQUESTPOSTPROCESSINGACTION,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.AudioRequestPostProcessingAction)
  })
_sym_db.RegisterMessage(AudioRequestPostProcessingAction)

AudioResponsePostProcessingAction = _reflection.GeneratedProtocolMessageType('AudioResponsePostProcessingAction', (_message.Message,), {
  'DESCRIPTOR' : _AUDIORESPONSEPOSTPROCESSINGACTION,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.AudioResponsePostProcessingAction)
  })
_sym_db.RegisterMessage(AudioResponsePostProcessingAction)

GetModelsResponse = _reflection.GeneratedProtocolMessageType('GetModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELSRESPONSE,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.GetModelsResponse)
  })
_sym_db.RegisterMessage(GetModelsResponse)

CreateEnrollmentRequest = _reflection.GeneratedProtocolMessageType('CreateEnrollmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLMENTREQUEST,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.CreateEnrollmentRequest)
  })
_sym_db.RegisterMessage(CreateEnrollmentRequest)

AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEREQUEST,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.AuthenticateRequest)
  })
_sym_db.RegisterMessage(AuthenticateRequest)

ValidateEventRequest = _reflection.GeneratedProtocolMessageType('ValidateEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEEVENTREQUEST,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.ValidateEventRequest)
  })
_sym_db.RegisterMessage(ValidateEventRequest)

CreateEnrolledEventRequest = _reflection.GeneratedProtocolMessageType('CreateEnrolledEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLEDEVENTREQUEST,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.CreateEnrolledEventRequest)
  })
_sym_db.RegisterMessage(CreateEnrolledEventRequest)

ValidateEnrolledEventRequest = _reflection.GeneratedProtocolMessageType('ValidateEnrolledEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEENROLLEDEVENTREQUEST,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.ValidateEnrolledEventRequest)
  })
_sym_db.RegisterMessage(ValidateEnrolledEventRequest)

TranscribeRequest = _reflection.GeneratedProtocolMessageType('TranscribeRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCRIBEREQUEST,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.TranscribeRequest)
  })
_sym_db.RegisterMessage(TranscribeRequest)

SynthesizeSpeechRequest = _reflection.GeneratedProtocolMessageType('SynthesizeSpeechRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNTHESIZESPEECHREQUEST,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.SynthesizeSpeechRequest)
  })
_sym_db.RegisterMessage(SynthesizeSpeechRequest)

CreateEnrollmentResponse = _reflection.GeneratedProtocolMessageType('CreateEnrollmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLMENTRESPONSE,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.CreateEnrollmentResponse)
  })
_sym_db.RegisterMessage(CreateEnrollmentResponse)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATERESPONSE,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.AuthenticateResponse)
  })
_sym_db.RegisterMessage(AuthenticateResponse)

ValidateEventResponse = _reflection.GeneratedProtocolMessageType('ValidateEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEEVENTRESPONSE,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.ValidateEventResponse)
  })
_sym_db.RegisterMessage(ValidateEventResponse)

ValidateEnrolledEventResponse = _reflection.GeneratedProtocolMessageType('ValidateEnrolledEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEENROLLEDEVENTRESPONSE,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.ValidateEnrolledEventResponse)
  })
_sym_db.RegisterMessage(ValidateEnrolledEventResponse)

TranscribeWord = _reflection.GeneratedProtocolMessageType('TranscribeWord', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCRIBEWORD,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.TranscribeWord)
  })
_sym_db.RegisterMessage(TranscribeWord)

TranscribeWordResponse = _reflection.GeneratedProtocolMessageType('TranscribeWordResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCRIBEWORDRESPONSE,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.TranscribeWordResponse)
  })
_sym_db.RegisterMessage(TranscribeWordResponse)

TranscribeResponse = _reflection.GeneratedProtocolMessageType('TranscribeResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCRIBERESPONSE,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.TranscribeResponse)
  })
_sym_db.RegisterMessage(TranscribeResponse)

SynthesizeSpeechResponse = _reflection.GeneratedProtocolMessageType('SynthesizeSpeechResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYNTHESIZESPEECHRESPONSE,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.SynthesizeSpeechResponse)
  })
_sym_db.RegisterMessage(SynthesizeSpeechResponse)

CreateEnrollmentConfig = _reflection.GeneratedProtocolMessageType('CreateEnrollmentConfig', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLMENTCONFIG,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.CreateEnrollmentConfig)
  })
_sym_db.RegisterMessage(CreateEnrollmentConfig)

AuthenticateConfig = _reflection.GeneratedProtocolMessageType('AuthenticateConfig', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATECONFIG,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.AuthenticateConfig)
  })
_sym_db.RegisterMessage(AuthenticateConfig)

ValidateEventConfig = _reflection.GeneratedProtocolMessageType('ValidateEventConfig', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEEVENTCONFIG,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.ValidateEventConfig)
  })
_sym_db.RegisterMessage(ValidateEventConfig)

CreateEnrollmentEventConfig = _reflection.GeneratedProtocolMessageType('CreateEnrollmentEventConfig', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLMENTEVENTCONFIG,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.CreateEnrollmentEventConfig)
  })
_sym_db.RegisterMessage(CreateEnrollmentEventConfig)

ValidateEnrolledEventConfig = _reflection.GeneratedProtocolMessageType('ValidateEnrolledEventConfig', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEENROLLEDEVENTCONFIG,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.ValidateEnrolledEventConfig)
  })
_sym_db.RegisterMessage(ValidateEnrolledEventConfig)

CustomVocabularyWords = _reflection.GeneratedProtocolMessageType('CustomVocabularyWords', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMVOCABULARYWORDS,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.CustomVocabularyWords)
  })
_sym_db.RegisterMessage(CustomVocabularyWords)

TranscribeConfig = _reflection.GeneratedProtocolMessageType('TranscribeConfig', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCRIBECONFIG,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.TranscribeConfig)
  })
_sym_db.RegisterMessage(TranscribeConfig)

AudioConfig = _reflection.GeneratedProtocolMessageType('AudioConfig', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOCONFIG,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.AudioConfig)
  })
_sym_db.RegisterMessage(AudioConfig)

VoiceSynthesisConfig = _reflection.GeneratedProtocolMessageType('VoiceSynthesisConfig', (_message.Message,), {
  'DESCRIPTOR' : _VOICESYNTHESISCONFIG,
  '__module__' : 'v1.audio.audio_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.audio.VoiceSynthesisConfig)
  })
_sym_db.RegisterMessage(VoiceSynthesisConfig)


DESCRIPTOR._options = None
_AUDIOREQUESTPOSTPROCESSINGACTION.fields_by_name['action']._options = None
_AUDIORESPONSEPOSTPROCESSINGACTION.fields_by_name['action']._options = None
_CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest']._options = None
_AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest']._options = None
_VALIDATEEVENTREQUEST.oneofs_by_name['streamingRequest']._options = None
_CREATEENROLLEDEVENTREQUEST.oneofs_by_name['streamingRequest']._options = None
_VALIDATEENROLLEDEVENTREQUEST.oneofs_by_name['streamingRequest']._options = None
_TRANSCRIBEREQUEST.oneofs_by_name['streamingRequest']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['audio']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['userId']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['deviceId']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['modelName']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['description']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['enrollmentNumUtterances']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['enrollmentDuration']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['referenceId']._options = None
_AUTHENTICATECONFIG.oneofs_by_name['authId']._options = None
_AUTHENTICATECONFIG.fields_by_name['audio']._options = None
_AUTHENTICATECONFIG.fields_by_name['enrollmentId']._options = None
_AUTHENTICATECONFIG.fields_by_name['sensitivity']._options = None
_AUTHENTICATECONFIG.fields_by_name['security']._options = None
_VALIDATEEVENTCONFIG.fields_by_name['audio']._options = None
_VALIDATEEVENTCONFIG.fields_by_name['modelName']._options = None
_VALIDATEEVENTCONFIG.fields_by_name['userId']._options = None
_VALIDATEEVENTCONFIG.fields_by_name['sensitivity']._options = None
_CREATEENROLLMENTEVENTCONFIG.fields_by_name['audio']._options = None
_CREATEENROLLMENTEVENTCONFIG.fields_by_name['userId']._options = None
_CREATEENROLLMENTEVENTCONFIG.fields_by_name['modelName']._options = None
_CREATEENROLLMENTEVENTCONFIG.fields_by_name['description']._options = None
_CREATEENROLLMENTEVENTCONFIG.fields_by_name['enrollmentNumUtterances']._options = None
_CREATEENROLLMENTEVENTCONFIG.fields_by_name['enrollmentDuration']._options = None
_CREATEENROLLMENTEVENTCONFIG.fields_by_name['referenceId']._options = None
_VALIDATEENROLLEDEVENTCONFIG.oneofs_by_name['authId']._options = None
_VALIDATEENROLLEDEVENTCONFIG.fields_by_name['audio']._options = None
_VALIDATEENROLLEDEVENTCONFIG.fields_by_name['enrollmentId']._options = None
_VALIDATEENROLLEDEVENTCONFIG.fields_by_name['sensitivity']._options = None
_CUSTOMVOCABULARYWORDS.fields_by_name['words']._options = None
_TRANSCRIBECONFIG.fields_by_name['audio']._options = None
_TRANSCRIBECONFIG.fields_by_name['modelName']._options = None
_TRANSCRIBECONFIG.fields_by_name['userId']._options = None
_AUDIOCONFIG.fields_by_name['encoding']._options = None
_AUDIOCONFIG.fields_by_name['sampleRateHertz']._options = None
_AUDIOCONFIG.fields_by_name['audioChannelCount']._options = None
_VOICESYNTHESISCONFIG.fields_by_name['modelName']._options = None
_VOICESYNTHESISCONFIG.fields_by_name['sampleRateHertz']._options = None

_AUDIOMODELS = _descriptor.ServiceDescriptor(
  name='AudioModels',
  full_name='sensory.api.v1.audio.AudioModels',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5951,
  serialized_end=6060,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetModels',
    full_name='sensory.api.v1.audio.AudioModels.GetModels',
    index=0,
    containing_service=None,
    input_type=_GETMODELSREQUEST,
    output_type=_GETMODELSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUDIOMODELS)

DESCRIPTOR.services_by_name['AudioModels'] = _AUDIOMODELS


_AUDIOBIOMETRICS = _descriptor.ServiceDescriptor(
  name='AudioBiometrics',
  full_name='sensory.api.v1.audio.AudioBiometrics',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=6063,
  serialized_end=6310,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateEnrollment',
    full_name='sensory.api.v1.audio.AudioBiometrics.CreateEnrollment',
    index=0,
    containing_service=None,
    input_type=_CREATEENROLLMENTREQUEST,
    output_type=_CREATEENROLLMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Authenticate',
    full_name='sensory.api.v1.audio.AudioBiometrics.Authenticate',
    index=1,
    containing_service=None,
    input_type=_AUTHENTICATEREQUEST,
    output_type=_AUTHENTICATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUDIOBIOMETRICS)

DESCRIPTOR.services_by_name['AudioBiometrics'] = _AUDIOBIOMETRICS


_AUDIOEVENTS = _descriptor.ServiceDescriptor(
  name='AudioEvents',
  full_name='sensory.api.v1.audio.AudioEvents',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=6313,
  serialized_end=6702,
  methods=[
  _descriptor.MethodDescriptor(
    name='ValidateEvent',
    full_name='sensory.api.v1.audio.AudioEvents.ValidateEvent',
    index=0,
    containing_service=None,
    input_type=_VALIDATEEVENTREQUEST,
    output_type=_VALIDATEEVENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateEnrolledEvent',
    full_name='sensory.api.v1.audio.AudioEvents.CreateEnrolledEvent',
    index=1,
    containing_service=None,
    input_type=_CREATEENROLLEDEVENTREQUEST,
    output_type=_CREATEENROLLMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidateEnrolledEvent',
    full_name='sensory.api.v1.audio.AudioEvents.ValidateEnrolledEvent',
    index=2,
    containing_service=None,
    input_type=_VALIDATEENROLLEDEVENTREQUEST,
    output_type=_VALIDATEENROLLEDEVENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUDIOEVENTS)

DESCRIPTOR.services_by_name['AudioEvents'] = _AUDIOEVENTS


_AUDIOTRANSCRIPTIONS = _descriptor.ServiceDescriptor(
  name='AudioTranscriptions',
  full_name='sensory.api.v1.audio.AudioTranscriptions',
  file=DESCRIPTOR,
  index=3,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=6704,
  serialized_end=6828,
  methods=[
  _descriptor.MethodDescriptor(
    name='Transcribe',
    full_name='sensory.api.v1.audio.AudioTranscriptions.Transcribe',
    index=0,
    containing_service=None,
    input_type=_TRANSCRIBEREQUEST,
    output_type=_TRANSCRIBERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUDIOTRANSCRIPTIONS)

DESCRIPTOR.services_by_name['AudioTranscriptions'] = _AUDIOTRANSCRIPTIONS


_AUDIOSYNTHESIS = _descriptor.ServiceDescriptor(
  name='AudioSynthesis',
  full_name='sensory.api.v1.audio.AudioSynthesis',
  file=DESCRIPTOR,
  index=4,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=6831,
  serialized_end=6966,
  methods=[
  _descriptor.MethodDescriptor(
    name='SynthesizeSpeech',
    full_name='sensory.api.v1.audio.AudioSynthesis.SynthesizeSpeech',
    index=0,
    containing_service=None,
    input_type=_SYNTHESIZESPEECHREQUEST,
    output_type=_SYNTHESIZESPEECHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUDIOSYNTHESIS)

DESCRIPTOR.services_by_name['AudioSynthesis'] = _AUDIOSYNTHESIS

# @@protoc_insertion_point(module_scope)
